@@ -9,7 +9,7 @@
 #'
 #' @keywords internal
 #' @noRd
-.verify_input <- function(selection, poss_selections){
+.verify_input <- function(selection, poss_selections) {
   # method <- match.arg(method, c('welch','mc','imhof'))
 
   selection1 <- tolower(selection)
@@ -18,10 +18,11 @@
 
   final_selection <- poss_selections[pmatch(selection1, poss_selections1)[1]]
 
-  if(is.na(final_selection)){
-    stop("Issue on the input '",deparse(substitute(selection)),
-         "'. See documentation and verify your choice.",
-         call. = FALSE)
+  if (is.na(final_selection)) {
+    stop("Issue on the input '", deparse(substitute(selection)),
+      "'. See documentation and verify your choice.",
+      call. = FALSE
+    )
   }
 
   final_selection
